# Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT

%bcond manpages 1
%global forgeurl https://gitlab.com/fedora/sigs/go/go-vendor-tools
%define tag v%{version_no_tilde %{quote:%nil}}

Name:           go-vendor-tools
Version:        0.5.1^29.20240808.d1dc767
%forgemeta
Release:        1%{?dist}
Summary:        Tools for handling Go library vendoring in Fedora [SEE NOTE IN DESCRIPTION]

# BSD-3-Clause: src/go_vendor_tools/archive.py
License:        MIT AND BSD-3-Clause
URL:            %{forgeurl}
Source0:        go-vendor-tools-0.5.1^29.20240808.d1dc767.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

%if %{with manpages}
BuildRequires:  scdoc
%endif

Recommends:     (askalono-cli or trivy)
Recommends:     go-vendor-tools+all


%global common_description %{expand:
go-vendor-tools provides tools and macros for handling Go library vendoring in
Fedora.

STABILITY NOTE:

go-vendor-tools is under active development and available in the stable Fedora
and Fedora EPEL repos for testing purposes.
Expect some breaking changes between releases.
Anyone using the `%%go_vendor_*` macros in active Fedora packages MUST join the
Fedora Golang Matrix room and Fedora Go SIG mailing list to be notified of any
major changes.}

%description %common_description


%package doc
Summary:        Documentation for go-vendor-tools
Enhances:       go-vendor-tools

%description doc %common_description


%prep
%autosetup -p1 


%generate_buildrequires
%pyproject_buildrequires -x all,test


%build
%pyproject_wheel
%if %{with manpages}
./doc/man/mkman.sh
%endif

mkdir -p bash_completions fish_completions zsh_completions
for bin in go_vendor_archive go_vendor_license; do
    register-python-argcomplete --shell bash "${bin}" > "bash_completions/${bin}"
    register-python-argcomplete --shell fish "${bin}" > "fish_completions/${bin}.fish"
    # Compatibility with old argcomplete versions
    if ! (register-python-argcomplete --shell zsh "${bin}" > "zsh_completions/_${bin}"); then
        echo "#compdef ${bin}" > "zsh_completions/_${bin}"
        echo -e "autoload -Uz bashcompinit\nbashcompinit" > "zsh_completions/_${bin}"
        cat "bash_completions/${bin}" >> "zsh_completions/_${bin}"
    fi
done


%install
%pyproject_install
# TODO(anyone): Use -l flag once supported by EL 9.
%pyproject_save_files go_vendor_tools

# Install RPM macros
install -Dpm 0644 rpm/macros.go_vendor_tools -t %{buildroot}%{_rpmmacrodir}

# Install documentation
mkdir -p %{buildroot}%{_docdir}/go-vendor-tools-doc
cp -rL doc/* %{buildroot}%{_docdir}/go-vendor-tools-doc

# Install manpages
%if %{with manpages}
install -Dpm 0644 doc/man/*.1 -t %{buildroot}%{_mandir}/man1/
%endif

# Install completions
install -Dpm 0644 bash_completions/* -t %{buildroot}%{bash_completions_dir}/
install -Dpm 0644 fish_completions/* -t %{buildroot}%{fish_completions_dir}/
install -Dpm 0644 zsh_completions/* -t %{buildroot}%{zsh_completions_dir}/


%check
%pytest


%files -f %{pyproject_files}
# Install top-level markdown files
%doc *.md
%license LICENSES/*
%{_bindir}/go_vendor*
%{bash_completions_dir}/go_vendor_*
%{fish_completions_dir}/go_vendor_*.fish
%{zsh_completions_dir}/_go_vendor_*
%{_rpmmacrodir}/macros.go_vendor_tools
%if %{with manpages}
%{_mandir}/man1/go*.1*
%endif

%files doc
%doc %{_docdir}/go-vendor-tools-doc/

%pyproject_extras_subpkg -n go-vendor-tools all

%changelog
* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^29.20240808.d1dc767-1
- packit: temporarily disable fedora-39 chroot

* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^28.20240808.54b9334-1
- tests integration: clean up specs and scripts and add scancode

* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^27.20240808.08c411a-1
- rpm: use %%{go_vendor_license_filelist} in the other macros

* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^26.20240808.1bb8214-1
- ci: disable Fedora 41 Python 3.13 tests for now

* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^25.20240808.bd4fa83-1
- lint: add editorconfig

* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^24.20240808.294fb6a-1
- tests autorestic: fix typos and add scancode support

* Thu Aug 08 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^23.20240808.7a3fd7e-1
- license_detection: add `scancode-toolkit`-based backend

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^22.20240807.a05ecbf-1
- LicenseDetector: add is_available() classmethod

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^21.20240807.91ab315-1
- lint: prefix private `_LicenseDataT` TypeVar with `_`

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^20.20240807.06ec040-1
- LicenseData: allow customizing combine_licenses call in subclasses

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^19.20240807.73834e7-1
- licensing combine_licenses: add recursive_simplify arg; correct types

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^18.20240807.2b28978-1
- go_vendor_license write_license_json: use pretty formatting for JSON

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^17.20240807.22f536c-1
- license_detection base: add docstring to `find_extra_license_files()`

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^16.20240807.568d68d-1
- dev pyright lsp: enable basic type checking

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^15.20240807.0042a5c-1
- go_vendor_license: properly test relative and absolute paths

* Wed Aug 07 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^14.20240807.2db4df4-1
- license_detection: clarify manual license entry variable names

* Tue Aug 06 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^13.20240806.33b6b90-1
- config licenses: remove total=False from TypedDicts

* Tue Aug 06 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^12.20240806.cc1447b-1
- license_detection: include PATENTS in EXTRA_LICENSE_FILE_REGEX

* Mon Aug 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^11.20240805.fc35cd9-1
- go_vendor_archive: add support for go workspaces

* Mon Aug 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^10.20240805.3211955-1
- doc: add note about project stability

* Fri Jul 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^9.20240705.3d3cc54-1
- nox integration: remove fclogr dependency

* Fri Jul 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^8.20240705.b227d49-1
- nox: set error_on_external_run

* Fri Jul 05 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^7.20240705.01951b3-1
- go_vendor_license: work around bug with old tomlkit versions

* Sun Jun 23 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^6.20240623.f09ff94-1
- go_vendor_license: fix printing of undetected licenses

* Fri May 03 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^5.20240503.887b35b-1
- license_detection: make askalono the default backend

* Fri May 03 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^4.20240503.a459863-1
- lint doc: enable pymarkdownlnt for the doc folder

* Fri May 03 2024 Brad Smith <bradley.g.smith@gmail.com> - 0.5.1^3.20240503.735e24d-1
- doc scenarios: add new upstream version scenario

* Thu May 02 2024 Brad Smith <bradley.g.smith@gmail.com> - 0.5.1^2.20240502.54a475f-1
- doc: update mkdocs URLs to go-sig Gitlab namespace

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1^1.20240411.fc9513a-1
- Post-release version bump

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1-1
- Release 0.5.1.

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.0-1
- Release 0.5.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0-1
- Release 0.4.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0~b1-1
- Release 0.4.0b1.

* Thu Mar 28 2024 Maxwell G <maxwell@gtmx.me> - 0.3.0-1
- Release 0.3.0.

* Sat Mar 16 2024 Maxwell G <maxwell@gtmx.me> - 0.2.0-1
- Release 0.2.0.

* Sat Mar 09 2024 Maxwell G <maxwell@gtmx.me> - 0.1.0-1
- Release 0.1.0.

* Tue Mar 05 2024 Maxwell G <maxwell@gtmx.me> - 0.0.1-1
- Release 0.0.1.
